==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabBindingListBuilder.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GitLabBindingListBuilder extends GitLabBindingListFluentImpl<GitLabBindingListBuilder> implements VisitableBuilder<GitLabBindingList,GitLabBindingListBuilder>{
  public GitLabBindingListBuilder() {
    this(false);
  }
  public GitLabBindingListBuilder(Boolean validationEnabled) {
    this(new GitLabBindingList(), validationEnabled);
  }
  public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent) {
    this(fluent, false);
  }
  public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GitLabBindingList(), validationEnabled);
  }
  public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,GitLabBindingList instance) {
    this(fluent, instance, false);
  }
  public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,GitLabBindingList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public GitLabBindingListBuilder(GitLabBindingList instance) {
    this(instance,false);
  }
  public GitLabBindingListBuilder(GitLabBindingList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  GitLabBindingListFluent<?> fluent;
  Boolean validationEnabled;
  public GitLabBindingList build() {
    GitLabBindingList buildable = new GitLabBindingList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> knative-model-6.8.1-sources.jar: io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabBindingListBuilder.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GitLabBindingListBuilder extends GitLabBindingListFluent<GitLabBindingListBuilder> implements VisitableBuilder<GitLabBindingList,GitLabBindingListBuilder>{
  public GitLabBindingListBuilder() {
    this(false);
  }
  public GitLabBindingListBuilder(Boolean validationEnabled) {
    this(new GitLabBindingList(), validationEnabled);
  }
  public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent) {
    this(fluent, false);
  }
  public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GitLabBindingList(), validationEnabled);
  }
  public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,GitLabBindingList instance) {
    this(fluent, instance, false);
  }
  public GitLabBindingListBuilder(GitLabBindingListFluent<?> fluent,GitLabBindingList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new GitLabBindingList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public GitLabBindingListBuilder(GitLabBindingList instance) {
    this(instance,false);
  }
  public GitLabBindingListBuilder(GitLabBindingList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new GitLabBindingList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  GitLabBindingListFluent<?> fluent;
  Boolean validationEnabled;
  public GitLabBindingList build() {
    GitLabBindingList buildable = new GitLabBindingList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
